@@ -1,5 +1,6 @@
 from fastapi import FastAPI
 from circlepacker.routers import health, solves
+from mangum import Mangum
 
 app = FastAPI()
 
@@ -20,3 +21,6 @@ app.include_router(
 @app.get("/")
 async def base():
     return "Circle Packer"
+
+
+handler = Mangum(app)
